@@ -217,7 +217,7 @@ getcp <- function(
                   subset=NULL                 
                  )
 {
-  if (class(x)!="Clman")
+  if (class(x)[1] != "Clman")
     stop("x must be of class 'Clman'")
   
   if (length(ispec)!=1)
@@ -261,7 +261,7 @@ deletecp <- function (
                       cpdelete
                      )
 {
-  if (class(x)!="Clman")
+  if (class(x)[1] != "Clman")
     stop("x must be of class 'Clman'")
     
   ptscon <- getcp(x,ispec)
@@ -280,7 +280,7 @@ addcp <- function (
                    cpadd
                   )
 {
-  if (class(x)!="Clman")
+  if (class(x)[1] != "Clman")
     stop("x must be of class 'Clman'")
     
   ptscon <- getcp(x,ispec)
@@ -291,4 +291,4 @@ addcp <- function (
   ptscon <- ptscon$ptscon$Wavelength
   x@cp[ispec,match(cpadd,x@wavelength,nomatch=0)] <- cpadd
   return(x)
-}
\ No newline at end of file
+}
